@@ -3,8 +3,6 @@ import pdb
 import sys
 
 from stoobly_agent.app.settings import Settings
-from stoobly_agent.lib.api.keys import organization_key
-from stoobly_agent.lib.api.users_resource import UsersResource
 
 from .helpers import ProjectFacade
 from .helpers.tabulate_print_service import tabulate_print
@@ -23,10 +21,20 @@ def project(ctx):
 )
 @click.option('--description', help='Project description.')
 @click.option('--organization-key', required=True, help='Project to create project in.')
+@click.option('--select', multiple=True, help='Select column(s) to display.')
+@click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 @click.argument('name')
 def create(**kwargs):
+    print_options = __select_print_options(kwargs)
+
     project = ProjectFacade(Settings.instance())
-    print(project.create(**kwargs))
+
+    try:
+        project_response = project.create(**kwargs)
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
+
+    __print([project_response], **print_options)
 
 @project.command(
     help="Show all projects"
@@ -39,46 +47,77 @@ def create(**kwargs):
 @click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 @click.argument('organization_key', required=False)
 def list(**kwargs):
+    print_options = __select_print_options(kwargs)
+    settings = Settings.instance()
+    project = ProjectFacade(settings)
+
     organization_key = kwargs['organization_key']
-    without_headers = kwargs['without_headers']
-    del kwargs['without_headers']
+
+    # If organization_key is not set, try to use current project's organization
+    if not organization_key:
+        try:
+            project_key = ProjectKey(settings.proxy.intercept.project_key)
+            organization_key = OrganizationKey.encode(project_key.organization_id)
+        except InvalidProjectKey as e:
+            pass
+
+    # If organization_key is not set, try to use current user's private organization
+    if not organization_key:
+        try:
+            user_profile = project.user_profile()
+        except AssertionError as e:
+            return print(e, file=sys.stderr)
 
-    project = ProjectFacade(Settings.instance())
-    if not kwargs['organization_key']:
-        user_profile = project.user_profile()
         organization_key = user_profile['organization_key']
-        kwargs['organization_key'] = organization_key
 
     validate_organization_key(organization_key)
 
-    projects_response = project.index(kwargs)
+    try:
+        kwargs['organization_key'] = organization_key
+        projects_response = project.index(kwargs)
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
 
     if len(projects_response['list']) == 0:
         print('No projects found.', file=sys.stderr)
     else:
-        tabulate_print(
-            projects_response['list'], 
-            filter=['created_at', 'organization_id', 'project_id', 'starred', 'updated_at'],
-            headers=not without_headers,
-            select=kwargs.get('select'),
-        )
+        __print(projects_response['list'], **print_options)
 
 @project.command(
-    help="Describe scenario"
+    help="Describe project"
 )
 @click.option('--select', multiple=True, help='Select column(s) to display.')
 @click.option('--without-headers', is_flag=True, default=False, help='Disable printing column headers.')
 @click.argument('project_key', required=False)
 def show(**kwargs):
+    print_options = __select_print_options(kwargs)
+
     settings = Settings.instance()
     project_key = resolve_project_key_and_validate(kwargs, settings)
-
     project = ProjectFacade(settings)
-    project_response = project.show(project_key)
 
+    try:
+        project_response = project.show(project_key)
+    except AssertionError as e:
+        return print(e, file=sys.stderr)
+
+    __print([project_response], **print_options)
+
+def __print(projects, **kwargs):
     tabulate_print(
-        [project_response], 
+        projects, 
         filter=['created_at', 'organization_id', 'project_id', 'starred', 'updated_at'],
         headers=not kwargs.get('without_headers'),
-        select=kwargs.get('select')
-    )
\ No newline at end of file
+        select=kwargs.get('select') or []
+    )
+
+def __select_print_options(kwargs):
+    print_options = {
+        'select': kwargs['select'],
+        'without_headers': kwargs['without_headers']
+    }
+
+    del kwargs['without_headers']
+    del kwargs['select']
+
+    return print_options
