@@ -7,9 +7,10 @@ from stoobly_agent.config.constants import env_vars
 from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
 from .app.api import run as run_api
-from .app.cli import ca_cert, config, feature, MainGroup, project, request
-from .app.proxy import INTERCEPT_MODES, run as run_proxy
+from .app.cli import ca_cert, config, feature, MainGroup, project, request, trace
+from .app.proxy import CONNECTION_STRATEGIES, INTERCEPT_MODES, run as run_proxy
 from .app.settings import Settings
+from .lib import logger
 from .lib.orm.migrate_service import migrate as migrate_database
 
 settings = Settings.instance()
@@ -32,6 +33,7 @@ main.add_command(ca_cert)
 main.add_command(config)
 main.add_command(feature)
 main.add_command(request)
+main.add_command(trace)
 
 if settings.cli.features.dev_tools:
     from .app.cli import dev_tools
@@ -52,8 +54,9 @@ if settings.cli.features.remote:
 )
 @ConditionalDecorator(lambda f: click.option('--api-url', help='API URL.')(f), is_remote)
 @ConditionalDecorator(lambda f: click.option('--headless', is_flag=True, default=False, help='Disable starting UI.')(f), is_remote)
+@click.option('--connection-strategy', help=', '.join(CONNECTION_STRATEGIES), type=click.Choice(CONNECTION_STRATEGIES))
 @click.option('--intercept-mode', help=', '.join(INTERCEPT_MODES), type=click.Choice(INTERCEPT_MODES))
-@click.option('--log-level', default='info', type=click.Choice(['debug', 'info', 'warning', 'error']), help='''
+@click.option('--log-level', default=logger.INFO, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), help='''
     Log levels can be "debug", "info", "warning", or "error"
 ''')
 @click.option('--proxy-host', default='0.0.0.0', help='Address to bind proxy to.')
@@ -65,7 +68,6 @@ if settings.cli.features.remote:
 ''')
 @click.option('--proxy-port', default=8080, help='Proxy service port.')
 @click.option('--ssl-insecure', is_flag=True, default=False, help='Do not verify upstream server SSL/TLS certificates.')
-@click.option('--test-script', help='Provide a custom script for testing.')
 @ConditionalDecorator(lambda f: click.option('--ui-host', default='0.0.0.0', help='Address to bind UI to.')(f), is_remote)
 @ConditionalDecorator(lambda f: click.option('--ui-port', default=4200, help='UI service port.')(f), is_remote)
 def run(**kwargs):
@@ -80,9 +82,6 @@ def run(**kwargs):
     if 'headless' in kwargs and not kwargs['headless']:
         run_api(**kwargs)
 
-    if kwargs['test_script']:
-        os.environ[env_vars.TEST_SCRIPT] = kwargs['test_script']
-
     if kwargs['intercept_mode'] and kwargs['intercept_mode'] not in INTERCEPT_MODES:
         print(f"Error: Invalid value for --intercept-mode, values: {', '.join(INTERCEPT_MODES)}", file=sys.stderr)
         sys.exit(1)
